@@ -57,118 +57,85 @@ int genmon_CreateConfigGUI (GtkWidget *vbox1,
     GtkWidget      *table1;
     GtkWidget      *label1;
     GtkWidget      *wTF_Cmd;
-    GtkWidget      *eventbox1;
-    GtkWidget      *alignment1;
-    GtkObject      *wSc_Period_adj;
+    GtkWidget      *eventbox1;    
+    GtkAdjustment  *wSc_Period_adj;
     GtkWidget      *wSc_Period;
     GtkWidget      *label2;
     GtkWidget      *wTB_Title;
     GtkWidget      *wTF_Title;
     GtkWidget      *hseparator10;
     GtkWidget      *wPB_Font;
-    GtkWidget      *alignment3;
     GtkWidget      *hbox4;
-    GtkWidget      *image2;
-    GtkWidget      *label11;
-    GtkTooltips    *tooltips;
 
-    tooltips = gtk_tooltips_new ();
-
-    table1 = gtk_table_new (3, 2, FALSE);
+    table1 = gtk_grid_new ();
+    gtk_grid_set_column_spacing(GTK_GRID (table1), 2);
+    gtk_grid_set_row_spacing(GTK_GRID (table1), 2);
     gtk_widget_show (table1);
     gtk_box_pack_start (GTK_BOX (vbox1), table1, FALSE, TRUE, 0);
 
     label1 = gtk_label_new (_("Command"));
     gtk_widget_show (label1);
-    gtk_table_attach (GTK_TABLE (table1), label1, 0, 1, 0, 1,
-        (GtkAttachOptions) (GTK_FILL),
-        (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table1), label1, 0, 0, 1, 1);
+        //(GtkAttachOptions) (GTK_FILL),
+        //(GtkAttachOptions) (0), 0, 0);
     gtk_label_set_justify (GTK_LABEL (label1), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (label1), 0, 0.5);
+    gtk_widget_set_valign (label1, GTK_ALIGN_CENTER);
 
     wTF_Cmd = gtk_entry_new ();
     gtk_widget_show (wTF_Cmd);
-    gtk_table_attach (GTK_TABLE (table1), wTF_Cmd, 1, 2, 0, 1,
-        (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-        (GtkAttachOptions) (0), 0, 0);
-    gtk_tooltips_set_tip (tooltips, wTF_Cmd,
-        _("Input the shell command to spawn, then press <Enter>"),
-        NULL);
+    gtk_grid_attach (GTK_GRID (table1), wTF_Cmd, 1, 0, 1, 1);
+    gtk_widget_set_tooltip_text (wTF_Cmd, "Input the shell command to spawn, then press <Enter>");
     gtk_entry_set_max_length (GTK_ENTRY (wTF_Cmd), 128);
 
     eventbox1 = gtk_event_box_new ();
     gtk_widget_show (eventbox1);
-    gtk_table_attach (GTK_TABLE (table1), eventbox1, 1, 2, 2, 3,
-        (GtkAttachOptions) (GTK_FILL),
-        (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (table1), eventbox1, 1, 2, 1, 1);
+    gtk_widget_set_valign(GTK_WIDGET(eventbox1), GTK_ALIGN_CENTER);
+    gtk_widget_set_halign(GTK_WIDGET(eventbox1), GTK_ALIGN_CENTER);
+    gtk_widget_set_vexpand(GTK_WIDGET(eventbox1), TRUE);
+    gtk_widget_set_hexpand(GTK_WIDGET(eventbox1), TRUE);
 
-    alignment1 = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment1);
-    gtk_container_add (GTK_CONTAINER (eventbox1), alignment1);
-
-    wSc_Period_adj = gtk_adjustment_new (15, 1, 60*60*24, 1, 1, 0);
-    wSc_Period = gtk_spin_button_new (GTK_ADJUSTMENT (wSc_Period_adj), 1, 0);
+    wSc_Period_adj = gtk_adjustment_new (15, .25, 60*60*24, .25, 1, 0);
+    wSc_Period = gtk_spin_button_new (GTK_ADJUSTMENT (wSc_Period_adj), .25, 2);
     gtk_widget_show (wSc_Period);
-    gtk_container_add (GTK_CONTAINER (alignment1), wSc_Period);
-    gtk_tooltips_set_tip (tooltips, wSc_Period,
-        _("Interval between 2 consecutive spawns"),
-        NULL);
+    gtk_container_add (GTK_CONTAINER (eventbox1), wSc_Period);
+    gtk_widget_set_tooltip_text (wSc_Period, "Interval between 2 consecutive spawns");
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (wSc_Period), TRUE);
 
     label2 = gtk_label_new (_("Period (s) "));
     gtk_widget_show (label2);
-    gtk_table_attach (GTK_TABLE (table1), label2, 0, 1, 2, 3,
-        (GtkAttachOptions) (GTK_FILL),
-        (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table1), label2, 0, 2, 1, 1);
+        //(GtkAttachOptions) (GTK_FILL),
+        //(GtkAttachOptions) (0), 0, 0);
     gtk_label_set_justify (GTK_LABEL (label2), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
+    gtk_widget_set_valign (label2, GTK_ALIGN_CENTER);
 
     wTB_Title = gtk_check_button_new_with_mnemonic (_("Label"));
     gtk_widget_show (wTB_Title);
-    gtk_table_attach (GTK_TABLE (table1), wTB_Title, 0, 1, 1, 2,
-        (GtkAttachOptions) (GTK_FILL),
-        (GtkAttachOptions) (0), 0, 0);
-    gtk_tooltips_set_tip (tooltips, wTB_Title, _("Tick to display label"),
-        NULL);
+    gtk_grid_attach (GTK_GRID (table1), wTB_Title, 0, 1, 1, 1);
+    gtk_widget_set_tooltip_text (wTB_Title, "Tick to display label");
 
     wTF_Title = gtk_entry_new ();
     gtk_widget_show (wTF_Title);
-    gtk_table_attach (GTK_TABLE (table1), wTF_Title, 1, 2, 1, 2,
-        (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-        (GtkAttachOptions) (0), 0, 0);
-    gtk_tooltips_set_tip (tooltips, wTF_Title,
-        _("Input the plugin label, then press <Enter>"),
-        NULL);
+    gtk_grid_attach (GTK_GRID (table1), wTF_Title, 1, 1, 1, 1);
+ 
+    gtk_widget_set_tooltip_text (wTF_Title, "Input the plugin label, then press <Enter>");
     gtk_entry_set_max_length (GTK_ENTRY (wTF_Title), 16);
     gtk_entry_set_text (GTK_ENTRY (wTF_Title), _("(genmon)"));
 
-    hseparator10 = gtk_hseparator_new ();
+    hseparator10 = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hseparator10);
     gtk_box_pack_start (GTK_BOX (vbox1), hseparator10, FALSE, FALSE, 0);
 
-    wPB_Font = gtk_button_new ();
+    wPB_Font = gtk_button_new_with_label (_("Select the display font..."));
     gtk_widget_show (wPB_Font);
-    gtk_box_pack_start (GTK_BOX (vbox1), wPB_Font, FALSE, FALSE, 0);
-    gtk_tooltips_set_tip (tooltips, wPB_Font, _("Press to change font"),
-        NULL);
-
-    alignment3 = gtk_alignment_new (0.5, 0.5, 0, 0);
-    gtk_widget_show (alignment3);
-    gtk_container_add (GTK_CONTAINER (wPB_Font), alignment3);
-
-    hbox4 = gtk_hbox_new (FALSE, 2);
+    gtk_box_pack_start (GTK_BOX (vbox1), wPB_Font, TRUE, TRUE, 0);
+    gtk_widget_set_tooltip_text (wPB_Font, "Press to change font...");
+            
+    hbox4 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
     gtk_widget_show (hbox4);
-    gtk_container_add (GTK_CONTAINER (alignment3), hbox4);
-
-    image2 = gtk_image_new_from_stock ("gtk-select-font", GTK_ICON_SIZE_BUTTON);
-    gtk_widget_show (image2);
-    gtk_box_pack_start (GTK_BOX (hbox4), image2, FALSE, FALSE, 0);
-
-    label11 = gtk_label_new_with_mnemonic (_("(Default font)"));
-    gtk_widget_show (label11);
-    gtk_box_pack_start (GTK_BOX (hbox4), label11, FALSE, FALSE, 0);
-    gtk_label_set_justify (GTK_LABEL (label11), GTK_JUSTIFY_LEFT);
-
+    gtk_container_add (GTK_CONTAINER (vbox1), hbox4);
+    
     if (p_poGUI) {
         COPYVAL (p_poGUI, wTF_Cmd);
         COPYVAL (p_poGUI, wTB_Title);
